@@ -14,20 +14,21 @@
 namespace Shopper {
 
 List* ListImport::from_plaintext(QString filename) {
-	std::ifstream file(filename.toAscii());
-	if (!file) {
-		return 0;
+	QFile file(filename);
+	if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+			return 0;
 	}
 	// convert to xml
-	std::stringstream xml;
-
+	QTextStream xml;
+	QTextStream in(&file);
 	xml << "<list name='" << filename << "' state='2'>";
 
 	int categoryId = 0;
 	bool categoryStarted = false;
-	std::string line;
-	while (std::getline(file, line)) {
-		if (line.size() > 0 && !isspace(line[0])) {
+	QString line;
+	while (!in.atEnd()){
+		line = in.readLine();
+		if (line.size() > 0 && !line[0].isSpace()) {
 			if (categoryStarted)
 				xml << "</category>";
 
@@ -35,13 +36,16 @@ List* ListImport::from_plaintext(QString filename) {
 			categoryStarted = true;
 		}
 
-		if (line.size() >= 1 && isspace(line[0])) {
+		if (line.size() >= 1 && line[0].isSpace()) {
 			if (!categoryStarted) {
 				xml << "<category name='no category' id='" << categoryId++ << "'>";
 				categoryStarted = true;
 			}
 
-			line.erase(0, line.find_first_not_of(" \t\n\r\f"));
+			int c=0;
+			while (line[c].isSpace() and c < line.size())
+				c++;
+			if (c) line.remove(0,c);
 			if (line.size() > 0)
 				xml << "<item wanted='1' bought='0' desc='" << line << "' note=''/>";
 		}
@@ -51,11 +55,9 @@ List* ListImport::from_plaintext(QString filename) {
 		xml << "</category>";
 	xml << "</list>";
 
-	std::string sxml(xml.str());
-	QString qxml(sxml.c_str());
-	DEBUG("import from : " <<filename <<"\n"<<qxml);
+	DEBUG("import from : " <<filename <<"\n"<<xml);
 
-	return new Shopper::List(qxml);
+	return new Shopper::List(xml.readAll());
 }
 
 }
