@@ -35,7 +35,7 @@ namespace Shopper
 	// LabelEntry - a label that turns into a textbox when clicked
 	LabelEntry::LabelEntry(QWidget *parent) :
 		QWidget(parent),
-		data(""),
+		data(QString()),
 		entry(0),
 		layout(this)
 	{
