@@ -251,7 +251,7 @@ void MainWindow::on_action_about()
 						  " was written by David Greaves (lbt). "
 						  "It is Free Software and licensed under the GPL.<br>"
 						  "I hope you enjoy using it.<br>"
-						  "<a href='http://shopper.garage.maemo.org/help.html'>Help can be found online</a><br>"
+						  "<a href='http://shopper.garage.maemo.org/help.html'>Click here for online help</a><br>"
 						  "Please let me know of any problems or suggestions at <a href='http://tinyurl.com/shopper-bugs'>the bug page</a>"));
 }
 
