@@ -35,7 +35,6 @@
 #include <cstdlib>
 #include "shopperList.h"
 
-
 using namespace std;
 
 namespace Shopper
@@ -56,17 +55,17 @@ namespace Shopper
 		// zero the id counters
 		Category::id_master = 0;
 		Item::id_master = 0;
-		QString tmp("name");
-		for (int at = 0; at != attrs.count(); at++) {
+		QString tmp(QLatin1String("name"));
+		for (int at = 0; at != attrs.count(); ++at) {
 			QString at_name = attrs.localName(at);
 			QString at_value = attrs.value(at);
-			if (at_name.toLower() == "name") {
+			if (at_name.toLower() == QLatin1String("name")) {
 				l->name = at_value;
-			} else if (at_name.toLower() == "state") {   // save as int? or human readable?
+			} else if (at_name.toLower() == QLatin1String("state")) {   // save as int? or human readable?
 				bool ok;
 				l->state = sState(at_value.toInt(&ok));
 				if (!ok) {
-					abort("Converting state failed\n");
+					abort(QLatin1String("Converting state failed\n"));
 				}
 			} else {
 				DEBUG("<list> Unknown attribute : " << at_name << "='" <<at_value<<"'\n");
@@ -80,13 +79,13 @@ namespace Shopper
 			exit(1); // FIXME throw?
 		}
 		c = new Category();
-		for (int at = 0; at != attrs.count(); at++) {
+		for (int at = 0; at != attrs.count(); ++at) {
 			QString at_name = attrs.localName(at);
 			QString at_value = attrs.value(at);
-			if (at_name.toLower() == "name") {
+			if (at_name.toLower() == QLatin1String("name")) {
 				c->name = at_value;
-			} else if (at_name.toLower() == "active") { // is this the category active?
-				if (at_value.toLower() == "true" or at_value == "1")
+			} else if (at_name.toLower() == QLatin1String("active")) { // is this the category active?
+				if (at_value.toLower() == QLatin1String("true") or at_value == QLatin1String("1"))
 					l->active_category = c;
 			} else {
 				DEBUG("<category> Unknown attribute : " << at_name << "='" <<at_value<<"'\n");
@@ -103,17 +102,17 @@ namespace Shopper
 
 		i = new Item();
 		i->category=c; // current category
-		for (int at = 0; at != attrs.count(); at++) {
+		for (int at = 0; at != attrs.count(); ++at) {
 			QString at_name = attrs.localName(at);
 			QString at_value = attrs.value(at);
-			if (at_name.toLower() == "desc") {
+			if (at_name.toLower() == QLatin1String("desc")) {
 				i->desc = at_value;
-			} else if (at_name.toLower() == "note") {
+			} else if (at_name.toLower() == QLatin1String("note")) {
 				i->note = at_value;
-			} else if (at_name.toLower() == "wanted") {
-				i->set_wanted(at_value.toLower() == "true" or at_value == "1");
-			} else if (at_name.toLower() == "bought") {
-				i->set_bought(at_value.toLower() == "true" or at_value == "1");
+			} else if (at_name.toLower() == QLatin1String("wanted")) {
+				i->set_wanted(at_value.toLower() == QLatin1String("true") or at_value == QLatin1String("1"));
+			} else if (at_name.toLower() == QLatin1String("bought")) {
+				i->set_bought(at_value.toLower() == QLatin1String("true") or at_value == QLatin1String("1"));
 			} else {
 				DEBUG("<item> Unknown attribute : " << at_name << "='" <<at_value<<"'\n");
 			}
@@ -129,11 +128,11 @@ namespace Shopper
 		Q_UNUSED(namespaceURI)
 		Q_UNUSED(qName)
 		DEBUG("adding " << el << "\n");
-		if (el.toLower() == "list") {
+		if (el.toLower() == QLatin1String("list")) {
 			start_list_el(attrs);
-		} else if (el.toLower() == "category") {
+		} else if (el.toLower() == QLatin1String("category")) {
 			start_cat_el(attrs);
-		} else if (el.toLower() == "item") {
+		} else if (el.toLower() == QLatin1String("item")) {
 			start_item_el(attrs);
 		} else {
 			throw ;
@@ -148,15 +147,15 @@ namespace Shopper
 		Q_UNUSED(namespaceURI)
 		Q_UNUSED(qName)
 		DEBUG("done " << el << "\n");
-		if (el.toLower() == "list") {
+		if (el.toLower() == QLatin1String("list")) {
 			l->resequence(); // Ensure the id's are sensible FIXME : not needed?
 			l = 0; // No current list
-		} else if (el.toLower() == "category") {
+		} else if (el.toLower() == QLatin1String("category")) {
 			// add the created cat to list
 			c->dbg();
 			c->items.sort(cmpItem);
 			c=0; // No current category
-		} else if (el.toLower() == "item") {
+		} else if (el.toLower() == QLatin1String("item")) {
 			// add the created item to list
 			i->dbg();
 			DEBUG("Assigned " << i->desc << " to category " << i->category->name << "\n");
@@ -200,21 +199,21 @@ namespace Shopper
 
 		DEBUG("in write\n");
 		out.writeStartDocument();
-		out.writeStartElement("list");
-		out.writeAttribute("name", l->name);
-		out.writeAttribute("state", QString::number(l->state));
-		for (List::pCategoryIter c = l->categories.begin(); c != l->categories.end(); c++) {
-			out.writeStartElement("category");
+		out.writeStartElement(QLatin1String("list"));
+		out.writeAttribute(QLatin1String("name"), l->name);
+		out.writeAttribute(QLatin1String("state"), QString::number(l->state));
+		for (List::pCategoryIter c = l->categories.begin(); c != l->categories.end(); ++c) {
+			out.writeStartElement(QLatin1String("category"));
 			if (l->active_category == *c)
-				out.writeAttribute("active", "1");
-			out.writeAttribute("name", qPrintable((*c)->name));
-			out.writeAttribute("id", QString::number((*c)->id));
-			for (Category::pItemIter i = (*c)->items.begin(); i != (*c)->items.end(); i++) {
-				out.writeStartElement("item");
-				out.writeAttribute("wanted", (*i)->wanted?"1":"0");
-				out.writeAttribute("bought", (*i)->bought?"1":"0");
-				out.writeAttribute("desc", qPrintable((*i)->desc));
-				out.writeAttribute("note", qPrintable((*i)->note));
+				out.writeAttribute(QLatin1String("active"), QLatin1String("1"));
+			out.writeAttribute(QLatin1String("name"), (*c)->name);
+			out.writeAttribute(QLatin1String("id"), QString::number((*c)->id));
+			for (Category::pItemIter i = (*c)->items.begin(); i != (*c)->items.end(); ++i) {
+				out.writeStartElement(QLatin1String("item"));
+				out.writeAttribute(QLatin1String("wanted"), (*i)->wanted?QLatin1String("1"):QLatin1String("0"));
+				out.writeAttribute(QLatin1String("bought"), (*i)->bought?QLatin1String("1"):QLatin1String("0"));
+				out.writeAttribute(QLatin1String("desc"), (*i)->desc);
+				out.writeAttribute(QLatin1String("note"), (*i)->note);
 				out.writeEndElement(); // /item
 			}
 		out.writeEndElement(); // /category
